@@ -11,4 +11,16 @@ from .base import (
     SubtractionIndicator,
     SummationIndicator,
 )
-from .financial import SimpleMovingAverage, SimpleMovingVariance, bollinger_band
+from .comparisons import SimpleMax, SimpleMin
+from .financial import bollinger_band
+from .mathematical import (
+    CosineIndicator,
+    LogarithmIndicator,
+    SineIndicator,
+    TangentIndicator,
+)
+from .statistical import (
+    SimpleHistoricalStats,
+    SimpleMovingAverage,
+    SimpleMovingVariance,
+)
